@@ -1,10 +1,10 @@
 '''This module contains step implementations that setup the load test scenario with parameters that is going to be used in the scenario they are defined in.'''
-from typing import cast
+from typing import Optional, cast
 
 import parse
 
 from behave.runner import Context
-from behave import register_type, given  # pylint: disable=no-name-in-module
+from behave import register_type, given, then  # pylint: disable=no-name-in-module
 from locust.exception import StopUser
 
 from grizzly_extras.text import permutation
@@ -13,6 +13,8 @@ from ...context import GrizzlyContext
 from ...testdata.utils import create_context_variable, resolve_variable
 from ...utils import merge_dicts
 from ...exceptions import RestartScenario
+from .._helpers import is_template
+from ...tasks import RequestTask, GrizzlyTask
 
 
 @parse.with_pattern(r'(iteration[s]?)')
@@ -76,24 +78,18 @@ def step_setup_iterations(context: Context, value: str, iteration_number: str) -
     ```
 
     Args:
-        iterations (int): number of iterations of the scenario
+        value (str): number of iterations of the scenario, can be a templatning string or a environment configuration variable
     '''
     grizzly = cast(GrizzlyContext, context.grizzly)
-    should_resolve = '{{' in value and '}}' in value or value[0] == '$'
-    iterations = int(round(float(resolve_variable(grizzly, value)), 0))
+    should_resolve = is_template(value) or value[0] == '$'
+    iterations = max(int(round(float(resolve_variable(grizzly, value)), 0)), 0)
+
+    if is_template(value):
+        grizzly.scenario.orphan_templates.append(value)
 
     if should_resolve and iterations < 1:
         iterations = 1
 
-    assert iterations >= 0, f'{value} resolved to {iterations} iterations, which is not valid'
-
-    # only strict grammar if there's a static value
-    if not should_resolve:
-        if iterations > 1 or iterations == 0:
-            assert iteration_number == 'iterations', 'when iterations is 0 or greather than 1, use "iterations"'
-        else:
-            assert iteration_number == 'iteration', 'when iterations is 1, use "iteration"'
-
     grizzly.scenario.iterations = iterations
 
 
@@ -119,15 +115,19 @@ def step_setup_variable_value(context: Context, name: str, value: str) -> None:
 
     Example:
 
-    ``` gherkin
+    ``` gherkin title="example.feature"
     Feature:
         Background:
             And ask for value of variable "messageID"
         Scenario:
             And value for variable "HelloWorld" is "default"
             And value for variable "AtomicIntegerIncrementer.mid1" is "{{ messageID }}"
+            And value for variable "AtomicIntegerIncrementer.persistent" is "1 | step=10, persist=True"
     ```
 
+    If the file `features/persistent/example.json` (name of feature file and `feature` extension replaced with `json`) exists, and contains an entry for
+    the variable, the initial value will be read from the file and override the value specified in the feature file.
+
     Args:
         name (str): variable name
         value (Any): initial value
@@ -138,10 +138,16 @@ def step_setup_variable_value(context: Context, name: str, value: str) -> None:
 
     try:
         # data type will be guessed when setting the variable
-        resolved_value = resolve_variable(grizzly, value, guess_datatype=False)
+        if name not in grizzly.state.persistent:
+            resolved_value = resolve_variable(grizzly, value, guess_datatype=False)
+            if is_template(value):
+                grizzly.scenario.orphan_templates.append(value)
+        else:
+            resolved_value = grizzly.state.persistent[name]
+
         grizzly.state.variables[name] = resolved_value
     except ValueError as e:
-        assert 0, str(e)
+        raise AssertionError(str(e))
 
 
 @given(u'set alias "{alias}" for variable "{variable}"')
@@ -229,6 +235,7 @@ def step_setup_restart_scenario_on_failure(context: Context) -> None:
     context.config.stop = False
 
 
+@then(u'metadata "{key}" is "{value}"')
 @given(u'metadata "{key}" is "{value}"')
 def step_setup_metadata(context: Context, key: str, value: str) -> None:
     '''Set a metadata (header) value to be used by the user when sending requests.
@@ -239,12 +246,25 @@ def step_setup_metadata(context: Context, key: str, value: str) -> None:
     And metadata "Content-Type" is "application/xml"
     And metadata "Ocp-Apim-Subscription-Key" is "9asdf00asdf00adsf034"
     ```
+
+    Or, for use in one request only, specify metadata after the request:
+    ``` gherkin
+    Then post request ...
+    And metadata "x-header" is "{{ value }}"
+    ```
     '''
 
     grizzly = cast(GrizzlyContext, context.grizzly)
     casted_value = resolve_variable(grizzly, value)
 
-    if grizzly.scenario.context.get('metadata', None) is None:
-        grizzly.scenario.context['metadata'] = {}
+    previous_task: Optional[GrizzlyTask] = None
+    if len(grizzly.scenario.tasks) > 0:
+        previous_task = grizzly.scenario.tasks[-1]
 
-    grizzly.scenario.context['metadata'].update({key: casted_value})
+    if isinstance(previous_task, RequestTask):
+        previous_task.add_metadata(key, value)
+    else:
+        if grizzly.scenario.context.get('metadata', None) is None:
+            grizzly.scenario.context['metadata'] = {}
+
+        grizzly.scenario.context['metadata'].update({key: casted_value})
