@@ -16,17 +16,20 @@ a step implementation is also needed.
 There are examples of this in the {@link framework.example}.
 '''
 from abc import ABC, ABCMeta, abstractmethod
-from typing import TYPE_CHECKING, Any, Callable, List, Type, Set, Optional, Union, Dict
+from typing import TYPE_CHECKING, Any, Callable, List, Type, Set, Optional
 from os import environ
 from pathlib import Path
 
+from grizzly_extras.transformer import TransformerContentType
+
 if TYPE_CHECKING:  # pragma: no cover
     from ..scenarios import GrizzlyScenario
     from ..context import GrizzlyContextScenario
+    from ..types import GrizzlyResponse
 
 
 class GrizzlyTask(ABC):
-    __template_attributes__: List[str]
+    __template_attributes__: List[str] = []
 
     _context_root: str
 
@@ -45,15 +48,8 @@ class GrizzlyTask(ABC):
         def is_template(value: str) -> bool:
             return '{{' in value and '}}' in value
 
-        # tasks with no @template decorator
-        if not hasattr(self, '__template_attributes__'):
-            return []
-
-        templates: Set[str] = set()
-        for attribute in self.__template_attributes__:
-            value = getattr(self, attribute, None)
-            if value is None:
-                continue
+        def _get_value_templates(value: Any) -> Set[str]:
+            templates: Set[str] = set()
 
             if isinstance(value, str):
                 try:
@@ -70,23 +66,41 @@ class GrizzlyTask(ABC):
                 for list_value in value:
                     if isinstance(list_value, GrizzlyTask):
                         templates.update(list_value.get_templates())
-                    elif is_template(list_value):
-                        templates.add(list_value)
+                    else:
+                        templates.update(_get_value_templates(list_value))
             elif isinstance(value, dict):
                 for dict_value in value.values():
                     if isinstance(dict_value, GrizzlyTask):
                         templates.update(dict_value.get_templates())
-                    elif is_template(dict_value):
-                        templates.add(dict_value)
+                    else:
+                        templates.update(_get_value_templates(dict_value))
             elif isinstance(value, GrizzlyTask):
                 templates.update(value.get_templates())
 
+            return templates
+
+        templates: Set[str] = set()
+        for attribute in self.__template_attributes__:
+            value = getattr(self, attribute, None)
+            if value is None:
+                continue
+
+            templates.update(_get_value_templates(value))
+
         return list(templates)
 
 
+class GrizzlyMetaRequestTask(GrizzlyTask, metaclass=ABCMeta):
+    content_type: TransformerContentType
+    name: Optional[str]
+    endpoint: str
+
+    def execute(self, parent: 'GrizzlyScenario') -> 'GrizzlyResponse':
+        raise NotImplementedError(f'{self.__class__.name} has not implemented "execute"')
+
+
 class GrizzlyTaskWrapper(GrizzlyTask, metaclass=ABCMeta):
     name: str
-    list: Union[List[GrizzlyTask], Dict[str, GrizzlyTask]]
 
     @abstractmethod
     def add(self, task: GrizzlyTask) -> None:
