@@ -116,7 +116,7 @@ class BlobStorageClientTask(ClientTask):
         return f'DefaultEndpointsProtocol={self._endpoints_protocol};AccountName={self.account_name};AccountKey={self.account_key};EndpointSuffix=core.windows.net'
 
     def get(self, parent: GrizzlyScenario) -> GrizzlyResponse:
-        return super().get(parent)
+        raise NotImplementedError(f'{self.__class__.__name__} has not implemented GET')
 
     def put(self, parent: GrizzlyScenario) -> GrizzlyResponse:
         source = parent.render(cast(str, self.source))
@@ -141,8 +141,16 @@ class BlobStorageClientTask(ClientTask):
 
             source = parent.render(source_file.read_text())
 
+            meta.update({'request': {
+                'url': f'{destination}@{self.container}',
+                'payload': source,
+                'metadata': None,
+            }})
+
             with self.service_client.get_blob_client(container=self.container, blob=destination) as blob_client:
                 blob_client.upload_blob(source, content_settings=content_settings)
                 meta['response_length'] = len(source)
 
+            meta.update({'response': {}})
+
         return None, None
