@@ -31,17 +31,19 @@ def test__parse_template(request_task: RequestTaskFixture) -> None:
 
     variables = _parse_templates(templates)
 
-    assert 'TestScenario_001' in variables
-    assert 'messageID' in variables['TestScenario_001']
-    assert 'AtomicIntegerIncrementer.messageID' in variables['TestScenario_001']
-    assert 'AtomicDate.now' in variables['TestScenario_001']
-    assert 'AtomicCsvRow.test.header1' in variables['TestScenario_001']
-    assert 'AtomicCsvRow.test.header2' in variables['TestScenario_001']
-    assert 'AtomicDirectoryContents.test' in variables['TestScenario_001']
-    assert 'a_sub_string' in variables['TestScenario_001']
-    assert 'a_string' in variables['TestScenario_001']
-    assert 'AtomicIntegerIncrementer.file_number' in variables['TestScenario_001']
-    assert len(variables['TestScenario_001']) == 9
+    assert variables == {
+        'TestScenario_001': {
+            'messageID',
+            'AtomicIntegerIncrementer.messageID',
+            'AtomicDate.now',
+            'AtomicCsvRow.test.header1',
+            'AtomicCsvRow.test.header2',
+            'AtomicDirectoryContents.test',
+            'a_sub_string',
+            'a_string',
+            'AtomicIntegerIncrementer.file_number',
+        },
+    }
 
 
 def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
@@ -61,9 +63,11 @@ def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
 
     variables = _parse_templates(templates)
 
-    assert 'TestScenario_001' in variables
-    assert 'AtomicIntegerIncrementer.file_number' in variables['TestScenario_001']
-    assert len(variables['TestScenario_001']) == 1
+    assert variables == {
+        'TestScenario_001': {
+            'AtomicIntegerIncrementer.file_number',
+        },
+    }
 
     source['result'] = {'FooBar': '{{ (AtomicIntegerIncrementer.file_number | int) }}'}
 
@@ -75,9 +79,11 @@ def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
 
     variables = _parse_templates(templates)
 
-    assert 'TestScenario_001' in variables
-    assert 'AtomicIntegerIncrementer.file_number' in variables['TestScenario_001']
-    assert len(variables['TestScenario_001']) == 1
+    assert variables == {
+        'TestScenario_001': {
+            'AtomicIntegerIncrementer.file_number',
+        },
+    }
 
     request.source = "{{ '%08d' % key[:6] | int }}_{{ guid }}_{{ AtomicDate.date }}_{{ '%012d' % AtomicIntegerIncrementer.file_number }}"
 
@@ -88,12 +94,14 @@ def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
 
     variables = _parse_templates(templates)
 
-    assert 'TestScenario_001' in variables
-    assert 'key' in variables['TestScenario_001']
-    assert 'guid' in variables['TestScenario_001']
-    assert 'AtomicDate.date' in variables['TestScenario_001']
-    assert 'AtomicIntegerIncrementer.file_number' in variables['TestScenario_001']
-    assert len(variables['TestScenario_001']) == 4
+    assert variables == {
+        'TestScenario_001': {
+            'key',
+            'guid',
+            'AtomicDate.date',
+            'AtomicIntegerIncrementer.file_number',
+        },
+    }
 
     source = {
         'result': {
@@ -102,6 +110,13 @@ def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
             'FooBar_3': '{{ ((value3 - 2) | int) + 1 }}',
             'FooBar_4': '{{ (4 * value40) + (5 - value41) }}',
             'FooBar_5': '{{ Atomic.test1 + Atomic.test2 + Atomic.test3 }}',
+            'FooBar_6': '{{ value6 / 10.0 }}',
+            'FooBar_7': '{{ value71 if value70 else value72 }}',
+            'FooBar_8': "{{ value80 in [value81, value82, 'foobar'] }}",
+            'FooBar_9': "{{ 'Hello ' ~ value9 ~ '!' }}",
+            'FooBar_10': '{{ datetime.now() }}',
+            'FooBar_11': '{{ value110 if value111 is divisibleby value112 }}',
+            'FooBar_12': '{{ value120 if not value121 or (value122 and value123) else value124 }}',
         }
     }
 
@@ -112,9 +127,21 @@ def test__parse_template_nested_pipe(request_task: RequestTaskFixture) -> None:
 
     variables = _parse_templates(templates)
 
-    print(variables)
-
-    assert variables == {'TestScenario_001': {'value1', 'value2', 'value3', 'value40', 'value41', 'Atomic.test1', 'Atomic.test2', 'Atomic.test3'}}
+    assert variables == {
+        'TestScenario_001': {
+            'value1',
+            'value2',
+            'value3',
+            'value40', 'value41',
+            'Atomic.test1', 'Atomic.test2', 'Atomic.test3',
+            'value6',
+            'value70', 'value71', 'value72',
+            'value80', 'value81', 'value82',
+            'value9',
+            'value110', 'value111', 'value112',
+            'value120', 'value121', 'value122', 'value123', 'value124',
+        },
+    }
 
 
 def test_get_template_variables() -> None:
@@ -146,8 +173,11 @@ def test_get_template_variables() -> None:
     expected_scenario_name = '_'.join([scenario.name, scenario.identifier])
 
     assert scenario.class_name == expected_scenario_name
-    assert expected_scenario_name in variables
-    assert 'AtomicRandomString.test' in variables[expected_scenario_name]
-    assert 'AtomicIntegerIncrementer.test' in variables[expected_scenario_name]
-    assert 'foo' in variables[expected_scenario_name]
-    assert 'env' in variables[expected_scenario_name]
+    assert variables == {
+        expected_scenario_name: {
+            'AtomicRandomString.test',
+            'AtomicIntegerIncrementer.test',
+            'foo',
+            'env',
+        },
+    }
